@@ -289,9 +289,9 @@ def fis_bs_lollipop(df,valor1,valor2,figsize=(12,4),dpi=100,linewidth=5,size=10,
     markers.set_color(color)
     xlocs, xlabs = plt.xticks()
     j = 0
-    for v in df_dinner.tip:
+    for v in df[valor2]:
         plt.text(xlocs[j], v+offset, int(v), ha='center', fontsize=textsize)
         j+=1
     plt.ylabel("")
     plt.yticks([])                                    
-    return f, ax
\ No newline at end of file
+    return f, ax
